@@ -6,6 +6,6 @@ use oEdtk::Config	qw(config_read);
 use oEdtk::DBAdmin	qw(db_connect create_SCHEMA);
 
 my $cfg = config_read('EDTK_DB');
-my $dbh = db_connect($cfg, 'EDTK_DSN_DBI');
+my $dbh = db_connect($cfg, 'EDTK_DBI_DSN');
 
 create_SCHEMA($dbh);
